@@ -5,7 +5,7 @@ A system for managing Debian-like repositories with support for multiple
 distributions, architectures, and components.
 """
 
-__version__ = "0.2.0"
+__version__ = "0.3.7"
 __author__ = "Viacheslav Bocharov"
 __email__ = "vb@jethome.com"
 
@@ -19,6 +19,9 @@ from debrepomanager.config import Config, ConfigError
 # Phase 4: GPG ✅
 from debrepomanager.gpg import GPGError, GPGManager
 
+# Phase 9: GPG Rotation ✅
+from debrepomanager.gpg_rotation import GPGRotationError, GPGRotationManager
+
 # v0.2: Metadata ✅
 from debrepomanager.metadata import MetadataError, MetadataManager
 
@@ -42,6 +45,8 @@ __all__ = [
     "AptlyError",
     "GPGManager",
     "GPGError",
+    "GPGRotationManager",
+    "GPGRotationError",
     "MetadataManager",
     "MetadataError",
     "PackageInfo",
