@@ -134,12 +134,23 @@ class AptlyManager:
         aptly_root = Path(self.config.get_aptly_root(codename))
         config_file = self._get_aptly_config_path(codename)
 
+        # Publish endpoint for correct directory structure
+        # Note: publish_base WITHOUT codename, because prefix in publish includes it
+        # Use named endpoint "filesystem:public" instead of empty "" which doesn't work
+        publish_root = Path(self.config.publish_base)
+
         aptly_config = {
             "rootDir": str(aptly_root),
             "architectures": self.config.get_architectures(),
             "gpgProvider": "gpg",
             "gpgDisableSign": False,
             "gpgDisableVerify": False,
+            "FileSystemPublishEndpoints": {
+                "public": {
+                    "rootDir": str(publish_root),
+                    "linkMethod": "symlink",
+                }
+            },
         }
 
         try:
@@ -318,7 +329,12 @@ class AptlyManager:
             True
         """
         repo_name = self._get_repo_name(codename, component)
-        prefix = f"{codename}/{component}"
+        # Use same prefix format as publish (with publish_prefix if set)
+        if self.config.publish_prefix:
+            prefix_path = f"{self.config.publish_prefix}/{codename}"
+        else:
+            prefix_path = codename
+        prefix = f"filesystem:public:{prefix_path}"
 
         try:
             # First, unpublish if published
@@ -382,12 +398,30 @@ class AptlyManager:
 
         publish_base = Path(self.config.publish_base)
 
-        # Path to new format (actual data location)
-        # /srv/repo/public/bookworm/jethome-tools/dists/jethome-tools
-        new_path = publish_base / codename / component / "dists" / component
+        # Path to new format (actual data location created by aptly)
+        # aptly publishes to: {rootDir}/{prefix}/dists/{distribution}/
+        # where prefix from publish command and distribution from -distribution = component
+        #
+        # When publish_prefix is empty:
+        #   prefix = "codename" (e.g., "trixie")
+        #   Result: /opt/repo/public/trixie/dists/{component}/
+        #
+        # When publish_prefix is set (e.g., "beta"):
+        #   prefix = "beta/codename" (e.g., "beta/trixie")
+        #   Result: /opt/repo/public/beta/trixie/dists/{component}/
+        if self.config.publish_prefix:
+            new_path = (
+                publish_base
+                / self.config.publish_prefix
+                / codename
+                / "dists"
+                / component
+            )
+        else:
+            new_path = publish_base / codename / "dists" / component
 
         # Path for old format (symlink location)
-        # /srv/repo/public/dists/bookworm/jethome-tools
+        # /opt/repo/public/dists/{codename}/{component}
         old_path = publish_base / "dists" / codename / component
 
         # Check if new format path exists
@@ -425,6 +459,9 @@ class AptlyManager:
                 f"Created dual format symlink: {old_path} -> {relative_path}"
             )
 
+            # Note: Old format APT requires nginx rewrite rules to work properly
+            # Symlinks alone are insufficient due to "main" component and pool isolation
+
         except OSError as e:
             raise AptlyError(f"Failed to create symlink {old_path}: {e}") from e
         except Exception as e:
@@ -455,7 +492,15 @@ class AptlyManager:
             >>> manager._publish_snapshot("bookworm", "jethome-tools", "snap-123")
             True
         """
-        prefix = f"{codename}/{component}"
+        # With FileSystemPublishEndpoints, prefix depends on publish_prefix:
+        # - Empty publish_prefix (stable): prefix = "trixie"
+        #   Result: /opt/repo/public/trixie/dists/{component}/
+        # - publish_prefix = "beta": prefix = "beta/trixie"
+        #   Result: /opt/repo/public/beta/trixie/dists/{component}/
+        if self.config.publish_prefix:
+            prefix = f"{self.config.publish_prefix}/{codename}"
+        else:
+            prefix = codename
 
         # Check GPG key available
         if not self.gpg.check_key_available():
@@ -467,6 +512,7 @@ class AptlyManager:
         try:
             if is_initial:
                 # Initial publish
+                # Use named endpoint "public:prefix" to use FileSystemPublishEndpoints["public"]
                 self._run_aptly(
                     [
                         "publish",
@@ -476,19 +522,20 @@ class AptlyManager:
                         "-gpg-key",
                         self.config.gpg_key_id,
                         snapshot_name,
-                        prefix,
+                        f"filesystem:public:{prefix}",  # "filesystem:public:prefix"
                     ],
                     codename,
                 )
                 self.logger.info(f"Published snapshot: {snapshot_name} at {prefix}")
             else:
                 # Switch existing publication
+                # Use named endpoint "public:prefix" to use FileSystemPublishEndpoints["public"]
                 self._run_aptly(
                     [
                         "publish",
                         "switch",
                         component,  # distribution
-                        prefix,
+                        f"filesystem:public:{prefix}",  # "filesystem:public:prefix"
                         snapshot_name,
                     ],
                     codename,
@@ -769,6 +816,69 @@ class AptlyManager:
             self.logger.error(f"Failed to list packages in {repo_name}")
             raise
 
+    def get_repo_stats(self, codename: str, component: str) -> dict:
+        """Get repository statistics (package count and size).
+
+        Args:
+            codename: Distribution codename
+            component: Repository component
+
+        Returns:
+            Dictionary with 'package_count' and 'size_bytes' keys
+
+        Raises:
+            AptlyError: If operation fails
+            ValueError: If repository doesn't exist
+
+        Example:
+            >>> stats = manager.get_repo_stats("bookworm", "jethome-tools")
+            >>> count = stats['package_count']
+            >>> size = stats['size_bytes']
+            >>> print(f"Packages: {count}, Size: {size}")
+            Packages: 42, Size: 1234567
+        """
+        repo_name = self._get_repo_name(codename, component)
+
+        # Check if repo exists
+        if not self.repo_exists(codename, component):
+            raise ValueError(f"Repository {repo_name} doesn't exist")
+
+        try:
+            result = self._run_aptly(["repo", "show", repo_name], codename)
+
+            # Parse output to extract statistics
+            package_count = 0
+            size_bytes = 0
+
+            for line in result.stdout.split("\n"):
+                line = line.strip()
+
+                # Look for "Number of packages: 123"
+                if line.startswith("Number of packages:"):
+                    try:
+                        package_count = int(line.split(":")[-1].strip())
+                    except ValueError:
+                        pass
+
+            # Calculate repository size by summing package files
+            # Note: This is an approximation based on pool directory
+            repo_root = self.config.get_aptly_root(codename)
+            pool_dir = Path(repo_root) / "public" / "pool"
+
+            if pool_dir.exists():
+                size_bytes = sum(
+                    f.stat().st_size for f in pool_dir.rglob("*.deb") if f.is_file()
+                )
+
+            return {
+                "package_count": package_count,
+                "size_bytes": size_bytes,
+            }
+
+        except AptlyError:
+            self.logger.error(f"Failed to get stats for {repo_name}")
+            raise
+
     def remove_packages(
         self,
         codename: str,
