@@ -601,6 +601,99 @@ Number of packages: 0
             manager.list_packages("bookworm", "nonexistent")
 
 
+class TestGetRepoStats:
+    """Tests for getting repository statistics."""
+
+    def test_get_repo_stats_success(self, manager, mocker, tmp_path):
+        """Test getting repository statistics."""
+        mocker.patch.object(manager, "repo_exists", return_value=True)
+
+        # Mock aptly repo show output
+        mock_run = mocker.patch("subprocess.run")
+        mock_run.return_value = mocker.Mock(
+            returncode=0,
+            stdout="""Name: jethome-tools-bookworm
+Comment:
+Default Distribution:
+Default Component:
+
+Number of packages: 42
+""",
+            stderr="",
+        )
+
+        # Mock pool directory with some fake .deb files
+        mock_pool_dir = tmp_path / "public" / "pool"
+        mock_pool_dir.mkdir(parents=True)
+
+        # Create fake .deb files
+        (mock_pool_dir / "pkg1.deb").write_bytes(b"x" * 1024)  # 1 KB
+        (mock_pool_dir / "pkg2.deb").write_bytes(b"x" * 2048)  # 2 KB
+
+        # Mock get_aptly_root to return our tmp_path
+        mocker.patch.object(
+            manager.config, "get_aptly_root", return_value=str(tmp_path)
+        )
+
+        stats = manager.get_repo_stats("bookworm", "jethome-tools")
+
+        assert stats["package_count"] == 42
+        assert stats["size_bytes"] == 3072  # 1024 + 2048
+
+    def test_get_repo_stats_empty_repo(self, manager, mocker, tmp_path):
+        """Test getting stats for empty repository."""
+        mocker.patch.object(manager, "repo_exists", return_value=True)
+
+        mock_run = mocker.patch("subprocess.run")
+        mock_run.return_value = mocker.Mock(
+            returncode=0,
+            stdout="""Name: test-repo
+Number of packages: 0
+""",
+            stderr="",
+        )
+
+        # Mock empty pool directory
+        mocker.patch.object(
+            manager.config, "get_aptly_root", return_value=str(tmp_path)
+        )
+
+        stats = manager.get_repo_stats("bookworm", "test")
+
+        assert stats["package_count"] == 0
+        assert stats["size_bytes"] == 0
+
+    def test_get_repo_stats_repo_not_exists(self, manager, mocker):
+        """Test getting stats for non-existent repo raises error."""
+        mocker.patch.object(manager, "repo_exists", return_value=False)
+
+        with pytest.raises(ValueError, match="doesn't exist"):
+            manager.get_repo_stats("bookworm", "nonexistent")
+
+    def test_get_repo_stats_no_pool_dir(self, manager, mocker, tmp_path):
+        """Test getting stats when pool directory doesn't exist."""
+        mocker.patch.object(manager, "repo_exists", return_value=True)
+
+        mock_run = mocker.patch("subprocess.run")
+        mock_run.return_value = mocker.Mock(
+            returncode=0,
+            stdout="""Name: test-repo
+Number of packages: 5
+""",
+            stderr="",
+        )
+
+        # Mock get_aptly_root to non-existent pool dir
+        mocker.patch.object(
+            manager.config, "get_aptly_root", return_value=str(tmp_path)
+        )
+
+        stats = manager.get_repo_stats("bookworm", "test")
+
+        assert stats["package_count"] == 5
+        assert stats["size_bytes"] == 0  # No pool dir = 0 bytes
+
+
 class TestGetPublishedSnapshot:
     """Tests for getting published snapshot."""
 
@@ -992,9 +1085,8 @@ class TestDualFormatSupport:
     def test_create_dual_format_symlinks(self, manager, tmp_path):
         """Test creating symlinks for old format access."""
         # Create new format directory structure
-        new_path = (
-            tmp_path / "repo" / "bookworm" / "jethome-tools" / "dists" / "jethome-tools"
-        )
+        # aptly creates: /{codename}/dists/{component}/ (when publish_prefix="")
+        new_path = tmp_path / "repo" / "bookworm" / "dists" / "jethome-tools"
         new_path.mkdir(parents=True, exist_ok=True)
 
         # Create a test file in new format location
@@ -1018,10 +1110,8 @@ class TestDualFormatSupport:
 
     def test_create_dual_format_symlinks_relative_path(self, manager, tmp_path):
         """Test symlinks use relative paths."""
-        # Create new format directory
-        new_path = (
-            tmp_path / "repo" / "bookworm" / "jethome-tools" / "dists" / "jethome-tools"
-        )
+        # Create new format directory (when publish_prefix="")
+        new_path = tmp_path / "repo" / "bookworm" / "dists" / "jethome-tools"
         new_path.mkdir(parents=True, exist_ok=True)
 
         manager._create_dual_format_symlinks("bookworm", "jethome-tools")
@@ -1037,10 +1127,8 @@ class TestDualFormatSupport:
 
     def test_create_dual_format_symlinks_update_existing(self, manager, tmp_path):
         """Test updating existing symlinks."""
-        # Create new format directory
-        new_path = (
-            tmp_path / "repo" / "bookworm" / "jethome-tools" / "dists" / "jethome-tools"
-        )
+        # Create new format directory (when publish_prefix="")
+        new_path = tmp_path / "repo" / "bookworm" / "dists" / "jethome-tools"
         new_path.mkdir(parents=True, exist_ok=True)
 
         old_path = tmp_path / "repo" / "dists" / "bookworm" / "jethome-tools"
@@ -1093,10 +1181,8 @@ class TestDualFormatSupport:
         manager.config._config["repositories"]["dual_format"]["enabled"] = True
         manager.config._config["repositories"]["dual_format"]["auto_symlink"] = True
 
-        # Create new format directory structure
-        new_path = (
-            tmp_path / "repo" / "bookworm" / "jethome-tools" / "dists" / "jethome-tools"
-        )
+        # Create new format directory structure (when publish_prefix="")
+        new_path = tmp_path / "repo" / "bookworm" / "dists" / "jethome-tools"
         new_path.mkdir(parents=True, exist_ok=True)
 
         mock_run = mocker.patch("subprocess.run")
