@@ -529,25 +529,60 @@ class TestListCommand:
         assert result.exit_code == 0
         assert "--codename" in result.output
         assert "--component" in result.output
+        assert "--stats" in result.output
 
     def test_list_all_repos(self, runner, test_config, mocker):
-        """Test listing all repositories."""
+        """Test listing all repositories grouped by codename."""
         mock_manager = mocker.Mock()
-        mock_manager.list_repos.return_value = ["repo1-bookworm", "repo2-noble"]
+        mock_metadata = mocker.Mock()
+        mock_metadata.list_repositories.return_value = [
+            {
+                "codename": "bookworm",
+                "component": "jethome-tools",
+                "created": "2024-01-01",
+            },
+            {
+                "codename": "bookworm",
+                "component": "jethome-armbian",
+                "created": "2024-01-01",
+            },
+            {
+                "codename": "noble",
+                "component": "jethome-tools",
+                "created": "2024-01-01",
+            },
+        ]
+        mock_manager.metadata = mock_metadata
 
         mocker.patch("debrepomanager.cli.AptlyManager", return_value=mock_manager)
 
         result = runner.invoke(cli, ["--config", test_config, "list"])
 
         assert result.exit_code == 0
-        assert "repo1-bookworm" in result.output
-        assert "repo2-noble" in result.output
-        assert "Total: 2" in result.output
+        assert "bookworm" in result.output
+        assert "noble" in result.output
+        assert "jethome-tools" in result.output
+        assert "jethome-armbian" in result.output
+        assert "3 repository(ies)" in result.output
+        assert "2 codename(s)" in result.output
 
     def test_list_repos_for_codename(self, runner, test_config, mocker):
         """Test listing repos for specific codename."""
         mock_manager = mocker.Mock()
-        mock_manager.list_repos.return_value = ["repo1-bookworm"]
+        mock_metadata = mocker.Mock()
+        mock_metadata.list_repositories.return_value = [
+            {
+                "codename": "bookworm",
+                "component": "jethome-tools",
+                "created": "2024-01-01",
+            },
+            {
+                "codename": "bookworm",
+                "component": "jethome-armbian",
+                "created": "2024-01-01",
+            },
+        ]
+        mock_manager.metadata = mock_metadata
 
         mocker.patch("debrepomanager.cli.AptlyManager", return_value=mock_manager)
 
@@ -557,7 +592,8 @@ class TestListCommand:
 
         assert result.exit_code == 0
         assert "bookworm" in result.output
-        assert "repo1-bookworm" in result.output
+        assert "jethome-tools" in result.output
+        assert "jethome-armbian" in result.output
 
     def test_list_packages_in_component(self, runner, test_config, mocker):
         """Test listing packages in specific component."""
@@ -588,14 +624,74 @@ class TestListCommand:
     def test_list_empty(self, runner, test_config, mocker):
         """Test listing when no repos exist."""
         mock_manager = mocker.Mock()
-        mock_manager.list_repos.return_value = []
+        mock_metadata = mocker.Mock()
+        mock_metadata.list_repositories.return_value = []
+        mock_manager.metadata = mock_metadata
 
         mocker.patch("debrepomanager.cli.AptlyManager", return_value=mock_manager)
 
         result = runner.invoke(cli, ["--config", test_config, "list"])
 
         assert result.exit_code == 0
-        assert "(none)" in result.output or "Total: 0" in result.output
+        assert "No repositories found" in result.output
+
+    def test_list_with_stats(self, runner, test_config, mocker):
+        """Test listing repositories with statistics."""
+        mock_manager = mocker.Mock()
+        mock_metadata = mocker.Mock()
+        mock_metadata.list_repositories.return_value = [
+            {
+                "codename": "bookworm",
+                "component": "jethome-tools",
+                "created": "2024-01-01",
+            },
+        ]
+        mock_manager.metadata = mock_metadata
+        mock_manager.get_repo_stats.return_value = {
+            "package_count": 42,
+            "size_bytes": 10485760,  # 10 MB
+        }
+
+        mocker.patch("debrepomanager.cli.AptlyManager", return_value=mock_manager)
+
+        result = runner.invoke(cli, ["--config", test_config, "list", "--stats"])
+
+        assert result.exit_code == 0
+        assert "bookworm" in result.output
+        assert "jethome-tools" in result.output
+        assert "42 packages" in result.output
+        assert "10.00 MB" in result.output
+
+    def test_list_packages_with_stats(self, runner, test_config, mocker):
+        """Test listing packages in component with statistics."""
+        mock_manager = mocker.Mock()
+        mock_manager.repo_exists.return_value = True
+        mock_manager.list_packages.return_value = ["pkg1_1.0_amd64"]
+        mock_manager.get_repo_stats.return_value = {
+            "package_count": 1,
+            "size_bytes": 5242880,  # 5 MB
+        }
+
+        mocker.patch("debrepomanager.cli.AptlyManager", return_value=mock_manager)
+
+        result = runner.invoke(
+            cli,
+            [
+                "--config",
+                test_config,
+                "list",
+                "--codename",
+                "bookworm",
+                "--component",
+                "jethome-tools",
+                "--stats",
+            ],
+        )
+
+        assert result.exit_code == 0
+        assert "Packages: 1" in result.output
+        assert "Size: 5.00 MB" in result.output
+        assert "pkg1_1.0_amd64" in result.output
 
 
 class TestCLIErrorHandling:
@@ -727,7 +823,9 @@ class TestCLIErrorHandling:
     def test_list_aptly_error(self, runner, test_config, mocker):
         """Test list handles AptlyError."""
         mock_manager = mocker.Mock()
-        mock_manager.list_repos.side_effect = AptlyError("list failed")
+        mock_metadata = mocker.Mock()
+        mock_metadata.list_repositories.side_effect = AptlyError("list failed")
+        mock_manager.metadata = mock_metadata
 
         mocker.patch("debrepomanager.cli.AptlyManager", return_value=mock_manager)
 
@@ -828,7 +926,9 @@ class TestCLIErrorHandling:
         from debrepomanager.config import ConfigError
 
         mock_manager = mocker.Mock()
-        mock_manager.list_repos.side_effect = ConfigError("config error")
+        mock_metadata = mocker.Mock()
+        mock_metadata.list_repositories.side_effect = ConfigError("config error")
+        mock_manager.metadata = mock_metadata
 
         mocker.patch("debrepomanager.cli.AptlyManager", return_value=mock_manager)
 
